@@ -42,10 +42,8 @@ def _get_rivalcfg_info():
     result = _make_title("Rivalcfg")
     result += "Version: %s\n" % VERSION
     if platform.system() == "Linux":
-        result += "udev rules installed: %a\n" % \
-            os.path.isfile(udev.RULES_FILE_PATH)
-        result += "udev rules up to date: %a\n" % \
-            udev.is_rules_file_up_to_date()
+        result += "udev rules installed: %a\n" % os.path.isfile(udev.RULES_FILE_PATH)
+        result += "udev rules up to date: %a\n" % udev.is_rules_file_up_to_date()
     result += "Installation path: %s\n" % os.path.dirname(__file__)
     return result
 
@@ -67,11 +65,12 @@ def _get_plugged_device_list():
         except Exception:
             pass
         result += "%04x:%04x | %02x | %s (firmware v%s)\n" % (
-                device["vendor_id"],
-                device["product_id"],
-                device["interface_number"],
-                device["product_string"],
-                firmware_version)
+            device["vendor_id"],
+            device["product_id"],
+            device["interface_number"],
+            device["product_string"],
+            firmware_version,
+        )
     return result
 
 
