@@ -152,6 +152,10 @@ import types
 from . import aerox3  # noqa: F401
 from . import aerox3_wireless_wired  # noqa: F401
 from . import aerox3_wireless_wireless  # noqa: F401
+from . import aerox5_wireless_wired  # noqa: F401
+from . import aerox5_wireless_wireless  # noqa: F401
+from . import aerox9_wireless_wired  # noqa: F401
+from . import aerox9_wireless_wireless  # noqa: F401
 from . import kanav2  # noqa: F401
 from . import kinzuv2  # noqa: F401
 from . import prime  # noqa: F401
